################# ANALYZA PREZITIA ##################
# chceme zistit rozdiel v preziti medzi skupinami ER+ a ER-
source("surv.plot.R") # nacitame funkciu pre zobrazenie Kaplan meierovych kriviek
load("TransBIG-expression.rdata")
ls()
### Kontrola spravnosti nacitania a vlastnosti suboru
is(X) # co je to za objekt
dim(X) # dimenzia tabulky
X[1:5,1:5] # nahlad prvych 5 riadkov a stlpcov...subor ma v riadkoch vzorky a v stlpcoch geny

#Načítanie klinickej informácie k vzorkom
clinical2=read.csv("TransBIG-Sample_info.csv", sep=";")
head(clinical2)

library(survival)

#Prepocitame dni sledovania na roky a spojime informacie o dlzke sledovania a vyskyte udalosti (relapsu)
rfs=clinical2$Time.RFS..days/365.25
rfs.event=clinical2$Event.RFS
RFS<-Surv(rfs, rfs.event)


# Porovnanie casu do vyskytu relapsu medzi ER+ a ER-
D<-data.frame(RFS=RFS, ER=clinical2$ER.pos.1.yes.)
# odhadneme median prezitia
(fit<-survfit(RFS~ ER,D))
# je rozdiel v preziti statisticky vyznamny?
(diff<-survdiff(RFS~ ER,D))
(p<-pchisq(diff$chisq, length(diff$n)-1, lower.tail = FALSE))
# nie je, aj ked trend tam je
survminer::ggsurvplot(fit, risk.table=TRUE, surv.median.line="hv",
                 risk.table.y.text.col=TRUE, risk.table.y.text=FALSE, legend.title="ER",
                 legend.labs=c("negative","positive"),risk.table.title="Patients in risk",
                 xlab="Year",pval=TRUE, pval.method=TRUE,conf.int=FALSE)



# Vplyv jednotlivych genov na cas do vyskytu relapsu
# Uprava dat
Xsc<-apply(X, 2, function(x) (x-median(x))/IQR(x))
# Coxov model
cox<-t(apply(Xsc,2, function(x) c(coefficients(summary(coxph(RFS~x)))[1,], cox.zph(coxph(RFS~x))$table[1,], exp(confint(coxph(RFS~x))[1,]))))

head(cox)# stlpce coef az Pr(>|z|) obsahuju vysledky modelu, stlpce rho az p obsahuju overenie proporcionality rizik, posledne 2 stlpce su intervaly spolahlivosti

# Interpretacia vysledkov
#http://www.sthda.com/english/wiki/cox-model-assumptions
#http://www.sthda.com/english/wiki/cox-proportional-hazards-model

sig<-which(cox[,"Pr(>|z|)"]<0.01)
# forest plot
forestplot::forestplot(rownames(cox)[sig], cox[,"exp(coef)"][sig], cox[,"2.5 %"][sig], cox[,"97.5 %"][sig], zero=1, boxsize=0.5, xlab="Hazard Ratio")

################# ANALYZA GENOVYCH SAD ##################
# Nacitanie dat
load("ER_vysledky.rdata")
load("GSE20194_MDACC_Expression.rdata")
clinical<-read.csv("GSE20194_MDACC_Sample_Info.csv", header=T)

# kontrola
head(ER_vysledky)
X[1:5,1:5]
head(clinical)

str(ER_vysledky)
str(X)
str(clinical)

# nacitanie drah a konverzia identifikatorov na gene symbol
library(graphite)
kegg<-pathways("hsapiens", "kegg")
head(kegg)
kegg[[1]]
nodes(kegg[[1]])
kegg<-convertIdentifiers(kegg, "symbol")
nodes(kegg[[1]])

# vytvorenie sad testovanych genov v jednotlivych drahach
keggSet<-lapply(kegg, function(x) substr(nodes(x), nchar("SYMBOL:")+1, nchar(nodes(x))))
keggSetFilter<-lapply(keggSet, function(x) 
    intersect(x, colnames(X)))

# celkova sada genov v drahach
keggSetAll<-unique(unlist(keggSet))
keggSetFilterAll<-unique(unlist(keggSetFilter))

## hypergeometricky test
library(Category)
degenes<-ER_vysledky$Gen[ER_vysledky$adjpval<0.1]

#mnoziny vyznamnych genov v jednotlivych drahach
siggenes<-replicate(length(keggSet), degenes, simplify = F)
siggenes<-Map(function(x, y) x[x %in% y], keggSetFilter,siggenes )

#aplikacia testu, kompetitivne vramci testovanych genov
hyperg_vysledky<-hyperg(keggSetFilter, siggenes, colnames(X), "over")
hyperg_vysledky$padj<-p.adjust(hyperg_vysledky$p, "BH")
head(hyperg_vysledky)

## GSA
GSA_vysledky<-GSA::GSA(t(X),as.numeric(clinical$ER_status), keggSet, colnames(X),
                       method="mean", resp.type="Two class unpaired", nperms=1000)

GSA_vysledky$pvalues.hi
GSA_vysledky$pvalues.lo

GSA::GSA.listsets(GSA_vysledky, geneset.names=names(keggSet),FDRcut=0.05)


## hypergeometricky test, genove sady podla Gene Ontology
library(GOstats)
# konverzia symbolickych mien na Entrez ID
degenes_entrez<-mapIds(org.Hs.eg.db, as.character(degenes), 'ENTREZID', 'SYMBOL')
allgenes_entrez<-mapIds(org.Hs.eg.db, colnames(X), 'ENTREZID', 'SYMBOL')
# konverzia nie je jednoznacna, nejednoznacnosti su riesene podla argumentu multiVals

# aplikacia testu
params <- new("GOHyperGParams",
               geneIds=unique(degenes_entrez),
               universeGeneIds=unique(allgenes_entrez),
               annotation="org.Hs.eg.db",
               ontology="MF",
               pvalueCutoff=1,
               conditional=FALSE,
               testDirection="over")
hgOver <- hyperGTest(params)

# vysledky
hgOver
hgOver_table<-summary(hgOver)
hgOver_table$q<-p.adjust(hgOver_table$Pvalue,"fdr")

head(hgOver_table)




